# Stylometry Bibliography

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.437118.svg)](https://doi.org/10.5281/zenodo.437118)

Bibtex copy of the Zotero bibliography on Stylometry: https://www.zotero.org/groups/stylometry_bibliography

# Description

## What is the scope of this bibliography?

The understanding of the term stylometry underlying the conceptual scope of the bibliography is relatively wide and covers any type of quantitative analysis of literary style. In practice, a large part of the entries are focused on stylometry understood as the theory and practice of authorship attribution with so-called non-traditional, quantitative methods. However, the bibliography endorses the idea of “stylometry beyond authorship” which means that any computational, preferably but not necessarily quantitative approaches to issues like author gender, literary genre or text type, time period or data of publication are also within the scope of the bibliography. Additionally, the bibliography also contains some forays into aspects not limited to literary texts, such as forensic linguistics or cognitive stylistics. Publications on statistics, machine learning, natural language processing or mainstream stylistics, literary theory and history are included only if they have a direct connection with an issue in stylometry as defined above.

The bibliography is open in scope with regard to publication formats, publication date, and language of publication. That is, besides monographs, journal articles and book chapters, it is open for (published) conference papers, technical reports (if publicly available) or blog posts, for instance. Likewise, there are currently 38 entries with a publication date between 1830 and 1950 and if we can identify more, they will be very welcome. In terms of languages, the bibliography is clearly dominated by English publications, but German, French and Spanish are also represented and again, suggestions for additional titles in languages other than English are highly welcome (see below, “How can I contribute?”).

## Where and in which formats is the bibliography available?

The bibliography is freely available online, in a variety of forms and formats:

* First of all, the bibliography can be browsed online here: https://www.zotero.org/groups/stylometry_bibliography/items/order/year/sort/desc
* This being a Zotero bibliography, the most efficient way of searching, sorting and using it is actually by using the Zotero plugin for Firefox: https://www.zotero.org/download/
* For users of a reference manager other than Zotero, an up-to-date bibtex version of the bibliography is also available: https://github.com/christofs/stylometry-bibliography (this is where you are right now)
* Finally, and just for good measure, a copy of the GitHub repository is archived at Zenodo.org: https://zenodo.org/record/437118 (DOI: 10.5281/zenodo.437118)

## How large is the bibliography?

The bibliography currently contains around 3400 items. This means it is by no means an exhaustive bibliography of all publications on the subject, but it does cover more ground than any other subject-specific bibliography available either in print or online. Also, the bibliography is meant to grow continually in the future and improve coverage of the field.

Some statistics: As of April 2017, the bibliography contains 1451 journal articles, 835 conference papers, 408 monographs, 381 book chapters, 108 B.A., M.A. or PhD. theses, 62 reports, 58 newspaper or magazine articles, and several dozens of entries with other document types. There are even two patents and one radio broadcast. A fun fact is that if you print this bibliography out on paper, it can easily run to almost 200 pages.

This size and our limited resources also means the bibliography is not perfect as it stands today. While we are pretty confident that for each entry, the authors’ names, the title and the date of publication are complete and correct, this is not always the case for the remaining pieces of information. This is especially true for the conference papers, which are a particularly challenging bibliographic entry type. Also, no attempt has been made to clean up the keywords. We do hope the bibliography is already useful as it is now and will improve it in the future.

## What if I just need some introductory readings?

We have you covered if rather than an exhaustive (and exhausting) list of readings, you need a manageable number of recommended introductory readings instead. For this purpose, we have defined a list of publications we consider particularly useful or important in this scenario. It contains four types of entries: papers that have proven to be milestones in the history of stylometry; survey papers, overviews and introductions that help newcomers get a grip of the history and structure of the field; important papers on more specific methodological aspects; and applications of stylometry to problems of authorship or other issues that demonstrate best practices or showcase the usefulness of stylometry in various areas.

There are two ways to access this limited list of recommended readings:

* In the online bibliography, a certain number of items are tagged with the keyword “recommended”: They can be found online at the following link: https://www.zotero.org/groups/stylometry_bibliography/items/tag/recommended.
* You can download a nicely formatted version of this list of recommended readings at the following link: https://github.com/christofs/stylometry-bibliography/tree/master/recommended.

## Who’s behind the bibliography?

The bibliography has been established based on bibliographies contributed by Joseph Rudman, Patrick Juola, Hugh Craig, Maciej Eder and Mike Kestemont. The initiative was launched in July 2016, in the mountains south of Kraków, Poland, during a meeting of a group of researchers in stylometry following the Digital Humanities Conference 2016. The initiative is set to be integrated into the ADHO Special Interest Group on Digital Literary Stylistics which will hopefully be accepted as such at the next Digital Humanities Conference in Montréal, Canada in August 2017. Joining, unifying and publishing the bibliography have been coordinated by Christof Schöch, with support from Marcel Schmitt.

## How can I contribute? (Glad you ask! ;-)

The best way to contribute is to send in any references you think are still missing, including your own newly-published items! We would especially appreciate suggestions of non-English publications, of which there are relatively few at the moment. Please send them to Christof Schöch (c.schoech@gmail.com) in bibtex format if at all possible, or with an ISBN or DOI, so that we can easily import them.
